==> jc-1.4.0.tar.gz: java/lang/reflect/Proxy__24ProxySignature.h <==
// final class java.lang.reflect.Proxy$ProxySignature

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d471dcfab49e270f java_lang_reflect_Proxy__24ProxySignature

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_reflect_Proxy__24ProxySignature_H_
#define _JC_java_lang_reflect_Proxy__24ProxySignature_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Method$object;
struct _jc_java_lang_reflect_Proxy__24ProxySignature$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_java_lang_reflect_Proxy__24ProxySignature$sub_refs	_jc_java_lang_reflect_Proxy__24ProxySignature$sub_refs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxySignature$sub_nonrefs	_jc_java_lang_reflect_Proxy__24ProxySignature$sub_nonrefs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxySignature$refs	_jc_java_lang_reflect_Proxy__24ProxySignature$refs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxySignature$nonrefs	_jc_java_lang_reflect_Proxy__24ProxySignature$nonrefs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxySignature$object	_jc_java_lang_reflect_Proxy__24ProxySignature$object;

typedef struct _jc_java_lang_reflect_Proxy__24ProxySignature$fields_struct	_jc_java_lang_reflect_Proxy__24ProxySignature$fields_struct;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxySignature$vmethods	_jc_java_lang_reflect_Proxy__24ProxySignature$vmethods;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxySignature$vtable	_jc_java_lang_reflect_Proxy__24ProxySignature$vtable;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxySignature$vtype	_jc_java_lang_reflect_Proxy__24ProxySignature$vtype;

// Class fields structure
struct _jc_java_lang_reflect_Proxy__24ProxySignature$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Error;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Object;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24RuntimeException;
	struct _jc_java_util_HashMap$object	*coreMethods;
};
extern _jc_java_lang_reflect_Proxy__24ProxySignature$fields_struct _jc_java_lang_reflect_Proxy__24ProxySignature$class_fields;

// Constructors
extern void _jc_java_lang_reflect_Proxy__24ProxySignature$method$_init$29c13095b73e79e4(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *, struct _jc_java_lang_reflect_Method$object *);

// Virtual methods
extern void _jc_java_lang_reflect_Proxy__24ProxySignature$method$checkCompatibility$5c4988a4d304fecb(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *);
extern jboolean _jc_java_lang_reflect_Proxy__24ProxySignature$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_lang_reflect_Proxy__24ProxySignature$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *);
extern void _jc_java_lang_reflect_Proxy__24ProxySignature$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *);

// Virtual method descriptors
extern _jc_method _jc_java_lang_reflect_Proxy__24ProxySignature$method_info$checkCompatibility$5c4988a4d304fecb;
extern _jc_method _jc_java_lang_reflect_Proxy__24ProxySignature$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_lang_reflect_Proxy__24ProxySignature$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_lang_reflect_Proxy__24ProxySignature$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_java_lang_reflect_Proxy__24ProxySignature$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_java_lang_Class$object *_jc_java_lang_reflect_Proxy__24ProxySignature$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_java_lang_reflect_Proxy__24ProxySignature$vmethods {
	void	(*checkCompatibility$5c4988a4d304fecb)(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *);
};

// Vtable
struct _jc_java_lang_reflect_Proxy__24ProxySignature$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_reflect_Proxy__24ProxySignature$vmethods	java_lang_reflect_Proxy__24ProxySignature;
};

// Vtype
struct _jc_java_lang_reflect_Proxy__24ProxySignature$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_Proxy__24ProxySignature$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy__24ProxySignature$sub_refs {
	struct _jc_java_lang_reflect_Method$object	*method;
	struct _jc_object	*exceptions;
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_Proxy__24ProxySignature$refs {
    _jc_java_lang_reflect_Proxy__24ProxySignature$sub_refs	java_lang_reflect_Proxy__24ProxySignature;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy__24ProxySignature$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_Proxy__24ProxySignature$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_reflect_Proxy__24ProxySignature$sub_nonrefs	java_lang_reflect_Proxy__24ProxySignature;
};

// Object instance structure
struct _jc_java_lang_reflect_Proxy__24ProxySignature$object {
	_jc_java_lang_reflect_Proxy__24ProxySignature$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_Proxy__24ProxySignature$vtype	*vtype;
	_jc_java_lang_reflect_Proxy__24ProxySignature$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_Proxy__24ProxySignature$vtype _jc_java_lang_reflect_Proxy__24ProxySignature$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_Proxy__24ProxySignature, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_Proxy__24ProxySignature$class_object;

#endif	/* _JC_java_lang_reflect_Proxy__24ProxySignature_H_ */

==> jc-1.4.6.tar.gz: java/lang/reflect/Proxy__24ProxySignature.h <==
// final class java.lang.reflect.Proxy$ProxySignature

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d471dcfab49e270f java_lang_reflect_Proxy__24ProxySignature

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_reflect_Proxy__24ProxySignature_H_
#define _JC_java_lang_reflect_Proxy__24ProxySignature_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_reflect_Method$object;
struct _jc_java_lang_reflect_Proxy__24ProxySignature$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_java_lang_reflect_Proxy__24ProxySignature$sub_refs	_jc_java_lang_reflect_Proxy__24ProxySignature$sub_refs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxySignature$sub_nonrefs	_jc_java_lang_reflect_Proxy__24ProxySignature$sub_nonrefs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxySignature$refs	_jc_java_lang_reflect_Proxy__24ProxySignature$refs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxySignature$nonrefs	_jc_java_lang_reflect_Proxy__24ProxySignature$nonrefs;
typedef struct _jc_java_lang_reflect_Proxy__24ProxySignature$object	_jc_java_lang_reflect_Proxy__24ProxySignature$object;

typedef struct _jc_java_lang_reflect_Proxy__24ProxySignature$fields_struct	_jc_java_lang_reflect_Proxy__24ProxySignature$fields_struct;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxySignature$vmethods	_jc_java_lang_reflect_Proxy__24ProxySignature$vmethods;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxySignature$vtable	_jc_java_lang_reflect_Proxy__24ProxySignature$vtable;
typedef const struct _jc_java_lang_reflect_Proxy__24ProxySignature$vtype	_jc_java_lang_reflect_Proxy__24ProxySignature$vtype;

// Class fields structure
struct _jc_java_lang_reflect_Proxy__24ProxySignature$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Error;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24Object;
	struct _jc_java_lang_Class$object	*class__24java__24lang__24RuntimeException;
	struct _jc_java_util_HashMap$object	*coreMethods;
};
extern _jc_java_lang_reflect_Proxy__24ProxySignature$fields_struct _jc_java_lang_reflect_Proxy__24ProxySignature$class_fields;

// Constructors
extern void _jc_java_lang_reflect_Proxy__24ProxySignature$method$_init$29c13095b73e79e4(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *, struct _jc_java_lang_reflect_Method$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_lang_reflect_Proxy__24ProxySignature$method$checkCompatibility$5c4988a4d304fecb(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_reflect_Proxy__24ProxySignature$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_lang_reflect_Proxy__24ProxySignature$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_reflect_Proxy__24ProxySignature$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_lang_reflect_Proxy__24ProxySignature$method_info$checkCompatibility$5c4988a4d304fecb;
extern _jc_method _jc_java_lang_reflect_Proxy__24ProxySignature$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_lang_reflect_Proxy__24ProxySignature$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_lang_reflect_Proxy__24ProxySignature$method_info$this$adc93fb6bf4cbffa;

// Static methods
extern void _jc_java_lang_reflect_Proxy__24ProxySignature$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_java_lang_reflect_Proxy__24ProxySignature$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_reflect_Proxy__24ProxySignature$vmethods {
	void	(*checkCompatibility$5c4988a4d304fecb)(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_lang_reflect_Proxy__24ProxySignature$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_lang_reflect_Proxy__24ProxySignature$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_reflect_Proxy__24ProxySignature$vmethods	java_lang_reflect_Proxy__24ProxySignature;
};

// Vtype
struct _jc_java_lang_reflect_Proxy__24ProxySignature$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_Proxy__24ProxySignature$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy__24ProxySignature$sub_refs {
	struct _jc_java_lang_reflect_Method$object	*method;
	struct _jc_object	*exceptions;
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_Proxy__24ProxySignature$refs {
    _jc_java_lang_reflect_Proxy__24ProxySignature$sub_refs	java_lang_reflect_Proxy__24ProxySignature;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_Proxy__24ProxySignature$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_Proxy__24ProxySignature$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_reflect_Proxy__24ProxySignature$sub_nonrefs	java_lang_reflect_Proxy__24ProxySignature;
};

// Object instance structure
struct _jc_java_lang_reflect_Proxy__24ProxySignature$object {
	_jc_java_lang_reflect_Proxy__24ProxySignature$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_Proxy__24ProxySignature$vtype	*vtype;
	_jc_java_lang_reflect_Proxy__24ProxySignature$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_Proxy__24ProxySignature$vtype _jc_java_lang_reflect_Proxy__24ProxySignature$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_Proxy__24ProxySignature, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_Proxy__24ProxySignature$class_object;

#endif	/* _JC_java_lang_reflect_Proxy__24ProxySignature_H_ */
